
This example shows the usage of the entity field binding for Vaadin Grid and Form components

Start it from the command line via 
```mvn spring-boot:run```

It will show an form with some input validations. 
Clicking the `Save` button will switch to the list that shows the entities as a Vaadin Grid.


### Description

It suffices to mark the grid as a form and select the controls that should be bound to the entity.

    @SeifeForm(forClass = Customer.class, generatorOptions = {"grid.gridClass"})
    public class CustomerGrid extends Grid<Customer> {

        /**
         * The recommended way is to name the fields just as in e.g. {@link Customer}, fields are then bound implicitly.
         */
        @SeifeBinding
        private Column<Customer> firstName;
    
        /**
         * However if necessary it can be explicitly bound via the name.
         */
        @SeifeBinding("lastName")
        private Column<Customer> name;
    // [..]

A model class such as a database entity exposes its attributes to the annotation processor via `@SeifeField`:

    @Entity
    @SeifeClass // just add this for the form binding, no special options needed
    public class Customer {
    
        @Id
        @GeneratedValue(strategy=GenerationType.AUTO)
        private Long id;
    
        /**
         * This field is exposed to the forms via @SeifeField
         */
        @SeifeField
        private String firstName;
    
        /**
         * The mandatory flag will create a mandatory input field whenever it is bound.
         */
        @SeifeField(mandatory = true)
        private String lastName;

All autogenerated code is marked as such, see the project.